datablock fxDTSBrickData (brick4xWaterData)
{
	brickFile = "./4x Water.blb";
	category = "Baseplates";
	subCategory = "Water";
	uiName = "4x Water";
	iconName = "Add-Ons/Brick_4x Water/4x Water";
   alwaysShowWireFrame = true;
};

datablock fxDTSBrickData (brick4xWaterRiverData)
{
	brickFile = "./4x River.blb";
	category = "Baseplates";
	subCategory = "Water";
	uiName = "4x River";
	iconName = "Add-Ons/Brick_4x Water/4x Water";
   alwaysShowWireFrame = true;
};

datablock fxDTSBrickData (brick4xWaterRapidsData)
{
	brickFile = "./4x Rapids.blb";
	category = "Baseplates";
	subCategory = "Water";
	uiName = "4x Rapids";
	iconName = "Add-Ons/Brick_4x Water/4x Water";
   alwaysShowWireFrame = true;
};


function brick4xWaterData::onLoadPlant(%data, %obj)
{
   brick4xWaterData::onPlant(%data, %obj);
}


function fxDTSBrick::createWaterZone(%brick)
{
   %color = getColorIDTable(%brick.colorID);
   %rgb = getWords(%color, 0, 2);
   %a = getWord(%color, 3) / 0.5;

   %pz = new PhysicalZone()
   {
      isWater = true;
      waterViscosity = 40;
      waterDensity = 1;
      waterColor = %rgb SPC %a;
      polyhedron = "0 0 0 1 0 0 0 -1 0 0 0 1";
   };
   if(!isObject(%pz))
   {
      error("ERROR: Could not create physical zone for brick4xCubeWater brick!");
      return;
   }
   missionCleanup.add(%pz);

   //set size
   %boxMin = getWords(%brick.getWorldBox(), 0, 2);
   %boxMax = getWords(%brick.getWorldBox(), 3, 5);
   %boxDiff = vectorSub(%boxMax, %boxMin);
   %boxDiff = vectorAdd(%boxDiff, "0 0 0.1"); 
   %pz.setScale(%boxDiff);
      
   //set position - this looks wierd because the the physical zone isn't positioned from it's center
   %posA = %brick.getWorldBoxCenter();
   %posB = %pz.getWorldBoxCenter();
   %posDiff = vectorSub(%posA, %posB);
   %posDiff = vectorSub(%posDiff, "0 0 0.1");
   %pz.setTransform(%posDiff);

   %brick.physicalZone = %pz;
}



function brick4xWaterData::onPlant(%data, %brick)
{
   %brick.setColliding(0);
   %brick.setRayCasting(0);
   %brick.setShapeFX(2);

   %brick.createWaterZone();  
}

function brick4xWaterData::onDeath(%data, %brick)
{
   if(isObject(%brick.physicalZone))
      %brick.physicalZone.delete();
}

function brick4xWaterData::onRemove(%data, %brick)
{
   if(isObject(%brick.physicalZone))
      %brick.physicalZone.delete();
}

function brick4xWaterData::onColorChange(%data, %brick)
{
   Parent::onColorChange(%data, %brick);
   %color = getColorIDTable(%brick.colorID);
   %rgb = getWords(%color, 0, 2);
   %a = getWord(%color, 3) / 0.5;

   if(isObject(%brick.physicalZone))
      %brick.physicalZone.setWaterColor(%rgb SPC %a);
}

function brick4xWaterData::onFakeDeath(%data, %brick)
{
   Parent::onFakeDeath(%data, %brick);
   if(isObject(%brick.physicalZone))
      %brick.physicalZone.deactivate();
}

function brick4xWaterData::onClearFakeDeath(%data, %brick)
{
   Parent::onClearFakeDeath(%data, %brick);
   if(isObject(%brick.physicalZone))
      %brick.physicalZone.activate();

   %brick.setColliding(0);
   %brick.setRayCasting(0);
}

function brick4xWaterData::disappear(%data, %brick, %time)
{
   Parent::disappear(%data,%brick,%time);
   if(%time == 0)
   {
      //disappear(0) = instantly re-appear
      if(isObject(%brick.physicalZone))
         %brick.physicalZone.activate();
      %brick.setColliding(0);
      %brick.setRayCasting(0);
   }
   else
   {
      if(isObject(%brick.physicalZone))
         %brick.physicalZone.deactivate();
   }
}

function brick4xWaterData::reappear(%data, %brick)
{
   Parent::reappear(%data,%brick);

   if(isObject(%brick.physicalZone))
      %brick.physicalZone.activate();

   %brick.setColliding(0);
   %brick.setRayCasting(0);
}



// River Water //
/////////////////
function brick4xWaterRiverData::onPlant(%data, %brick) {
   brick4xWaterData::onPlant(%data, %brick);
   %brick.physicalZone.setAppliedForce(vectorScale(%brick.getForwardVector(), 1000));
}

function brick4xWaterRiverData::onDeath(%data, %brick)
{
   brick4xWaterData::onDeath(%data, %brick);
}

function brick4xWaterRiverData::onRemove(%data, %brick)
{
   brick4xWaterData::onRemove(%data, %brick);
}

function brick4xWaterRiverData::onColorChange(%data, %brick)
{
   brick4xWaterData::onColorChange(%data, %brick);
}

function brick4xWaterRiverData::onFakeDeath(%data, %brick)
{
   brick4xWaterData::onFakeDeath(%data, %brick);
}

function brick4xWaterRiverData::onClearFakeDeath(%data, %brick)
{
   brick4xWaterData::onClearFakeDeath(%data, %brick);
}

function brick4xWaterRiverData::disappear(%data, %brick, %time)
{
   brick4xWaterData::disappear(%data, %brick, %time);
}

function brick4xWaterRiverData::reappear(%data, %brick)
{
   brick4xWaterData::reappear(%data, %brick);
}
/////////////////


// Rapids //
////////////
function brick4xWaterRapidsData::onPlant(%data, %brick)
{
   brick4xWaterData::onPlant(%data, %brick);
   %brick.physicalZone.setAppliedForce(vectorScale(%brick.getForwardVector(), 3000));
}

function brick4xWaterRapidsData::onDeath(%data, %brick)
{
   brick4xWaterData::onDeath(%data, %brick);
}

function brick4xWaterRapidsData::onRemove(%data, %brick)
{
   brick4xWaterData::onRemove(%data, %brick);
}

function brick4xWaterRapidsData::onColorChange(%data, %brick)
{
   brick4xWaterData::onColorChange(%data, %brick);
}

function brick4xWaterRapidsData::onFakeDeath(%data, %brick)
{
   brick4xWaterData::onFakeDeath(%data, %brick);
}

function brick4xWaterRapidsData::onClearFakeDeath(%data, %brick)
{
   brick4xWaterData::onClearFakeDeath(%data, %brick);
}

function brick4xWaterRapidsData::disappear(%data, %brick, %time)
{
   brick4xWaterData::disappear(%data, %brick, %time);
}

function brick4xWaterRapidsData::reappear(%data, %brick)
{
   brick4xWaterData::reappear(%data, %brick);
}
